@@ -1169,12 +1169,11 @@ class Client(metaclass=SingletonClass):
             )
         else:
             localtrack_folder = aiopath.AsyncPath(folder)
-
+        if not await localtrack_folder.exists():
+            localtrack_folder = self._config_folder / "music"
         from pylav.players.query.local_files import LocalFile
 
-        await self.lib_db_manager.get_config().update_localtrack_folder(
-            str(await discord.utils.maybe_coroutine(localtrack_folder.absolute))
-        )
+        await self.lib_db_manager.get_config().update_localtrack_folder(await localtrack_folder.absolute())
         await LocalFile.add_root_folder(path=localtrack_folder, create=True)
         return localtrack_folder
 
@@ -1399,7 +1398,7 @@ class Client(metaclass=SingletonClass):
                     await Track.build_track(
                         data=response.tracks[0],
                         node=node,
-                        query=await Query.from_string(response.tracks[0].info.uri),
+                        query=None,
                         requester=requester.id,
                     )
                 )
@@ -1434,7 +1433,7 @@ class Client(metaclass=SingletonClass):
                     await Track.build_track(
                         data=track,
                         node=node,
-                        query=await Query.from_string(track.info.uri),
+                        query=None,
                         requester=requester.id,
                     )
                 )
@@ -1459,7 +1458,7 @@ class Client(metaclass=SingletonClass):
                 await Track.build_track(
                     data=response.tracks[0],
                     node=node,
-                    query=new_query,
+                    query=sub_query,
                     requester=requester.id,
                 )
             )
@@ -1571,6 +1570,8 @@ class Client(metaclass=SingletonClass):
         }
         if data["loadType"] == "LOAD_FAILED":
             data["exception"] = {"cause": "No tracks returned", "severity": "COMMON", "message": "No tracks found"}
+        else:
+            data["exception"] = None
         node = await self.node_manager.find_best_node()
         while not node:
             await asyncio.sleep(0.1)
